{% extends 'admin/change_list.html' %}
{% load admin_list %}

{% block object-tools-items %}
    {% change_list_object_tools %}
    <li>
        <a href="./scan/" class="addlink">
            Scan Code
        </a>
    </li>
{% endblock %}
